/*
 * Copyright (c) 2007, Dennis M. Sosnoski All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following
 * disclaimer. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 * following disclaimer in the documentation and/or other materials provided with the distribution. Neither the name of
 * JiBX nor the names of its contributors may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.jibx.schema.generator;

import org.jibx.custom.classes.ClassCustom;

/**
 * Holder for details about an enumeration type to be included in the schema definition. An instance of this class is
 * created for each enumeration type found. The actual generation process may be either in-line or as a separate
 * simpleType, depending on whether the same enumeration is used more than once.
 * 
 * @author Dennis M. Sosnoski
 */
public class EnumDetail
{
    /** Enumeration class customization information. */
    private final ClassCustom m_custom;
    
    /** Global type definition flag. */
    private boolean m_isGlobal;
    
    /**
     * Constructor.
     * 
     * @param cust
     */
    public EnumDetail(ClassCustom cust) {
        m_custom = cust;
    }
    
    /**
     * Check if global type definition.
     * 
     * @return flag
     */
    public boolean isGlobal() {
        return m_isGlobal;
    }
    
    /**
     * Set global type definition.
     * 
     * @param global
     */
    public void setGlobal(boolean global) {
        m_isGlobal = global;
    }
    
    /**
     * Get class customization information.
     * 
     * @return custom
     */
    public ClassCustom getCustom() {
        return m_custom;
    }
}